@@ -1,5 +1,26 @@
 var NAVTREEINDEX7 =
 {
+"structpw__core__events.html#a6cf547297486e97c8969a1e08d837955":[10,0,27,2],
+"structpw__core__events.html#a8d568483182f9bdd13d8d4acbac462b7":[10,0,27,8],
+"structpw__core__events.html#a9a930f32ad895727dffbeb6ae4c6e04d":[10,0,27,6],
+"structpw__core__events.html#aa6aae56a5a9eb60fd5a308bec837b0e6":[10,0,27,4],
+"structpw__core__events.html#ada596905cb8c963eee644a638b6628c2":[10,0,27,5],
+"structpw__core__events.html#ae99597f5f149475172942064d4911961":[10,0,27,1],
+"structpw__core__events.html#aeaf261e59f9a58b5005418abf669271a":[10,0,27,0],
+"structpw__core__info.html":[10,0,28],
+"structpw__core__info.html#a11e9dea8aeb559ad12730b2741447d94":[10,0,28,5],
+"structpw__core__info.html#a25d93390dbafcb433827ec29c195404f":[10,0,28,0],
+"structpw__core__info.html#a3e394e50023a597dafb391887249d4eb":[10,0,28,7],
+"structpw__core__info.html#ab93eadf54d48e19762c4e6ebf5595083":[10,0,28,1],
+"structpw__core__info.html#ace1c72a0b6d18567a1156b2d961f63ca":[10,0,28,3],
+"structpw__core__info.html#ad294c9fa79558c75141a731c4d812b42":[10,0,28,6],
+"structpw__core__info.html#ade7cf9abf36e9cd82fe49ffa95159a2f":[10,0,28,2],
+"structpw__core__info.html#ae0fb9270f0212f68c7343b03fb9dc401":[10,0,28,4],
+"structpw__core__methods.html":[10,0,29],
+"structpw__core__methods.html#a05db653bcc20405f5b6ce5ccbe215703":[10,0,29,0],
+"structpw__core__methods.html#a23e319c72a886a40464d74e2e19f27f9":[10,0,29,6],
+"structpw__core__methods.html#a460ee1de46fe6e281c576cbe54841309":[10,0,29,2],
+"structpw__core__methods.html#a47721985e4d0b24474f5598d0d94b6c5":[10,0,29,5],
 "structpw__core__methods.html#a7e77a9289cd4ba827a7082109d207459":[10,0,29,1],
 "structpw__core__methods.html#a96ae294d1a899b90a6a8d3458a300fe2":[10,0,29,4],
 "structpw__core__methods.html#aa5ee0b92d1e85c741adcaa93a04622fa":[10,0,29,3],
@@ -228,26 +249,5 @@ var NAVTREEINDEX7 =
 "structpw__node__methods.html#a01dbc165d13370efdb6a54a5c3f40f41":[10,0,80,0],
 "structpw__node__methods.html#a0fee61facfa842f9be5b55815d78f49a":[10,0,80,3],
 "structpw__node__methods.html#a1f28beb1b607ebd270f2e06b4f9a5266":[10,0,80,1],
-"structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569":[10,0,80,5],
-"structpw__node__methods.html#a66986c115ef6b4046c22774ea438a3ad":[10,0,80,4],
-"structpw__node__methods.html#a9f04049f6b62d408dacdefe1aafcc802":[10,0,80,2],
-"structpw__permission.html":[10,0,81],
-"structpw__permission.html#a317a76bba04bd0dcad6e5bca65f9fa92":[10,0,81,0],
-"structpw__permission.html#ac890cf00fa67d8667c9be52276e8a6f3":[10,0,81,1],
-"structpw__port__events.html":[10,0,83],
-"structpw__port__events.html#a287b7ffb7f8f5b99b82bdd61d137cb1f":[10,0,83,0],
-"structpw__port__events.html#ab9b6466b9ef1ed29b53c585e6d7d5885":[10,0,83,2],
-"structpw__port__events.html#ac3ad235f94b8be2c65b694c8ebf26457":[10,0,83,1],
-"structpw__port__info.html":[10,0,84],
-"structpw__port__info.html#a016b0b8ee30c88e43179f634c3549ada":[10,0,84,5],
-"structpw__port__info.html#a3c95bbed7080e2f033b133409315f31a":[10,0,84,3],
-"structpw__port__info.html#a5131d23e86aef3c0d1727a6aa6359e9c":[10,0,84,4],
-"structpw__port__info.html#a59e2afe4f65b5f74eb7a28f51fb958aa":[10,0,84,0],
-"structpw__port__info.html#ab8bd7cf30a25d379e02bfc66c5692c64":[10,0,84,2],
-"structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2":[10,0,84,1],
-"structpw__port__methods.html":[10,0,85],
-"structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a":[10,0,85,2],
-"structpw__port__methods.html#a77b4f3e654eb54c6066faa61fa478186":[10,0,85,3],
-"structpw__port__methods.html#a902dc57cb5eaae752960a0667ff10ab8":[10,0,85,1],
-"structpw__port__methods.html#adbe08858422d830443b9f111cd6d44bd":[10,0,85,0]
+"structpw__node__methods.html#a44bb3efe45f8a5c763cc62daaa099569":[10,0,80,5]
 };
